===================================================
django-content-editor -- Editing structured content
===================================================

Django’s builtin admin application provides a really good and usable
administration interface for creating and updating content.
``django-content-editor`` extends Django’s inlines mechanism with an interface
and tools for managing and rendering heterogenous collections of content as are
often necessary for content management systems. For example, articles may be
composed of text blocks with images and videos interspersed throughout.

`Documentation on Read the Docs <http://django-content-editor.readthedocs.org/en/latest/>`_

.. image:: https://github.com/matthiask/django-content-editor/actions/workflows/tests.yml/badge.svg
    :target: https://github.com/matthiask/django-content-editor/
    :alt: CI Status

.. image:: https://readthedocs.org/projects/django-content-editor/badge/?version=latest
    :target: https://django-content-editor.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
